@@ -1,45 +1,55 @@
 package Games::Bingo;
 
-# $Id: Bingo.pm,v 1.11 2003/05/14 16:36:11 jonasbn Exp $
+# $Id: Bingo.pm,v 1.14 2003/05/16 09:59:01 jonasbn Exp $
 
 use strict;
 use integer;
 use POSIX qw(floor);
 use vars qw($VERSION);
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 sub new {
-	my $class = shift;
+	my ($class, $ceiling) = @_;
 	
 	my $self = bless {
-		_list => [],
+		_numbers => [],
 	}, $class || ref $class;
+
+	if ($ceiling) {
+		my @ary;
+		$self->init(\@ary, $ceiling);
+		push @{$self->{'_numbers'}}, @ary; 
+	}
+	return $self;
 }
 
 sub init {
-	my $self = shift;
-	my $numbers = shift;
-	my $ceiling = shift;
+	my ($self, $numbers, $ceiling) = @_;
 	
-	for(my $i = 1; $i < ($ceiling + 1); $i++) { push @$numbers, $i; }
+	for(my $i = 1; $i < ($ceiling + 1); $i++) { 
+		push @{$numbers}, $i; 
+	}
 }
 
 sub play {
-	my $self = shift;
-	my $numbers = shift;
-	
-	my $index = POSIX::floor(rand(scalar @$numbers));
-	my $number = $numbers->[$index];
-	splice(@$numbers,  $index, 1);
-	
+	my ($self, $numbers) = @_;
+
+	my $number;
+	if ($numbers) {
+		my $index = $self->random(scalar @{$numbers});
+		$number = $numbers->[$index];
+		splice(@{$numbers},  $index, 1);	
+	} else {	
+		my $index = $self->random(scalar @{$self->{'_numbers'}});
+		$number = $self->{'_numbers'}->[$index];
+		splice(@{$self->{'_numbers'}},  $index, 1);
+	}
 	return $number;
 }
 
 sub take {
-	my $self = shift;
-    my $taken = shift;
-    my $take = shift;
+	my ($self, $taken, $take) = @_;
 
     my $take_modified = sprintf("%02d", $take);
     my ($x, $y) = $take_modified =~ m/^(\d{1})(\d{1})$/o;
@@ -47,13 +57,19 @@ sub take {
     $taken->[$x][$y] = $take_modified;
 }
 
+sub random {
+	my ($self, $number) = @_;
+
+	return POSIX::floor(rand($number));
+}
+
 1;
 
 __END__
 
 =head1 NAME
 
-Games::Bingo - a Bingo Game Perl implementation
+Games::Bingo - a bingo game Perl implementation
 
 =cut
 
@@ -61,6 +77,18 @@ Games::Bingo - a Bingo Game Perl implementation
 
 C<< use Games::Bingo; >>
 
+C<< my $bingo = Games::Bingo-E<gt>new(90); >>
+
+C<< my $number = $bingo-E<gt>play(); >>
+
+C<< my @taken; >>
+
+C<< $bingo-E<gt>take(\@taken, $number); >>
+
+or
+
+C<< use Games::Bingo; >>
+
 C<< my $bingo = Games::Bingo-E<gt>new(); >>
 
 C<< my @numbers; >>
@@ -69,6 +97,8 @@ C<< $bingo-E<gt>init(\@numbers, 90); >>
 
 C<< my $number = $bingo-E<gt>play(\@numbers); >>
 
+C<< my @taken; >>
+
 C<< $bingo-E<gt>take(\@taken, $number); >>
 
 =cut
@@ -81,14 +111,17 @@ to the B<TODO> section (below).
 
 =cut
 
-=head2 METHODS
+=head1 METHODS
 
 This are the central methods of Games::Bingo
 
 =head2 new
 
-The constructor is quite simple for now and is only quite proforma, but
-will be put to use later.
+The constructor is quite simple. It can either be called without any
+paramters and then followed by a call to B<init> see below. Or the
+ceiling for the numbers (stored internally) can be given as a
+parameter, the latter is the recommeded use, please refer to the
+B<SYNOPSIS>.
 
 =head2 init
 
@@ -96,12 +129,19 @@ This method takes two parameters. An array reference and a ceiling, the
 method will push numbers onto the array reference from 1 to ceiling
 (including the ceiling). Initializing the numbers for the game.
 
+The use of init is not recommended, use the constructor in the
+recommended way instead.
+
 =head2 play
 
 The B<play> is one of the essential methods in the game, it takes an
 array reference and returns a random number from the array referenced
 to. The reference shrinks with one with each call.
 
+The recommended way is though to use the internally stored array, where
+play then takes no arguments, please refer to B<new> and B<init> and
+the B<SYNOPSIS>.
+
 =head2 take
 
 The B<take> method is the memory of the game. It takes to parameters, a
@@ -112,6 +152,14 @@ Since the first program to use the class/module was a console based the
 take method organizes the numbers in an array of array for a nicer
 presentation. This will probably be changed later (if necessary).
 
+=head2 random
+
+The encapsulation of the rand function. Takes a number as a paramtere
+and returns a number between 0 and the number given as a parameter just
+as rand (% perldoc -f rand).
+
+The result is rounded down using POSIX::floor
+
 =cut
 
 =head1 SEE ALSO
